@@ -6,6 +6,7 @@ import docutils.nodes as nodes
 from sphinx.application import Sphinx
 
 from .descriptionparser import get_description
+from .metaparser import get_meta_description
 from .titleparser import get_title
 
 import os
@@ -28,10 +29,10 @@ IMAGE_MIME_TYPES = {
 }
 
 
-def make_tag(property: str, content: str) -> str:
+def make_tag(property: str, content: str, type_: str = "property") -> str:
     # Parse quotation, so they won't break html tags if smart quotes are disabled
     content = content.replace('"', "&quot;")
-    return f'<meta property="{property}" content="{content}" />\n  '
+    return f'<meta {type_}="{property}" content="{content}" />'
 
 
 def get_tags(
@@ -45,6 +46,7 @@ def get_tags(
     if fields is None:
         fields = {}
     tags = {}
+    meta_tags = {}  # For non-og meta tags
 
     # Set length of description
     try:
@@ -67,12 +69,12 @@ def get_tags(
     # type tag
     tags["og:type"] = config["ogp_type"]
 
-    if os.getenv("READTHEDOCS") and config["ogp_site_url"] is None:
+    if os.getenv("READTHEDOCS") and not config["ogp_site_url"]:
         # readthedocs uses html_baseurl for sphinx > 1.8
         parse_result = urlparse(config["html_baseurl"])
 
         if config["html_baseurl"] is None:
-            raise EnvironmentError("ReadTheDocs did not provide a valid canonical URL!")
+            raise OSError("ReadTheDocs did not provide a valid canonical URL!")
 
         # Grab root url from canonical url
         config["ogp_site_url"] = urlunparse(
@@ -88,16 +90,19 @@ def get_tags(
 
     # url tag
     # Get the URL of the specific page
-    if context["builder"] == "dirhtml":
-        page_url = urljoin(config["ogp_site_url"], context["pagename"] + "/")
-    else:
-        page_url = urljoin(
-            config["ogp_site_url"], context["pagename"] + context["file_suffix"]
-        )
+    page_url = urljoin(
+        config["ogp_site_url"], app.builder.get_target_uri(context["pagename"])
+    )
     tags["og:url"] = page_url
 
-    # site name tag
-    site_name = config["ogp_site_name"]
+    # site name tag, False disables, default to project if ogp_site_name not
+    # set.
+    if config["ogp_site_name"] is False:
+        site_name = None
+    elif config["ogp_site_name"] is None:
+        site_name = config["project"]
+    else:
+        site_name = config["ogp_site_name"]
     if site_name:
         tags["og:site_name"] = site_name
 
@@ -105,6 +110,11 @@ def get_tags(
     if description:
         tags["og:description"] = description
 
+        if config["ogp_enable_meta_description"] and not get_meta_description(
+            context["metatags"]
+        ):
+            meta_tags["description"] = description
+
     # image tag
     # Get basic values from config
     if "og:image" in fields:
@@ -119,6 +129,7 @@ def get_tags(
 
     fields.pop("og:image:alt", None)
 
+    first_image = None
     if ogp_use_first_image:
         first_image = doctree.next_node(nodes.image)
         if (
@@ -127,6 +138,8 @@ def get_tags(
         ):
             image_url = first_image["uri"]
             ogp_image_alt = first_image.get("alt", None)
+        else:
+            first_image = None
 
     if image_url:
         # temporarily disable relative image paths with field lists
@@ -134,12 +147,12 @@ def get_tags(
             image_url_parsed = urlparse(image_url)
             if not image_url_parsed.scheme:
                 # Relative image path detected, relative to the source. Make absolute.
-                if config["ogp_image"]:
+                if first_image:
+                    root = page_url
+                else:  # ogp_image is set
                     # ogp_image is defined as being relative to the site root.
                     # This workaround is to keep that functionality from breaking.
                     root = config["ogp_site_url"]
-                else:
-                    root = page_url
 
                 image_url = urljoin(root, image_url_parsed.path)
             tags["og:image"] = image_url
@@ -155,8 +168,13 @@ def get_tags(
     # arbitrary tags and overrides
     tags.update({k: v for k, v in fields.items() if k.startswith("og:")})
 
-    return "\n" + "\n".join(
-        [make_tag(p, c) for p, c in tags.items()] + config["ogp_custom_meta_tags"]
+    return (
+        "\n".join(
+            [make_tag(p, c) for p, c in tags.items()]
+            + [make_tag(p, c, "name") for p, c in meta_tags.items()]
+            + config["ogp_custom_meta_tags"]
+        )
+        + "\n"
     )
 
 
@@ -172,7 +190,9 @@ def html_page_context(
 
 
 def setup(app: Sphinx) -> Dict[str, Any]:
-    app.add_config_value("ogp_site_url", None, "html")
+    # ogp_site_url="" allows relative by default, even though it's not
+    # officially supported by OGP.
+    app.add_config_value("ogp_site_url", "", "html")
     app.add_config_value("ogp_description_length", DEFAULT_DESCRIPTION_LENGTH, "html")
     app.add_config_value("ogp_image", None, "html")
     app.add_config_value("ogp_image_alt", None, "html")
@@ -180,6 +200,7 @@ def setup(app: Sphinx) -> Dict[str, Any]:
     app.add_config_value("ogp_type", "website", "html")
     app.add_config_value("ogp_site_name", None, "html")
     app.add_config_value("ogp_custom_meta_tags", [], "html")
+    app.add_config_value("ogp_enable_meta_description", True, "html")
 
     app.connect("html-page-context", html_page_context)
 
