@@ -5,5 +5,5 @@ exclude_patterns = ["_build"]
 
 html_theme = "basic"
 
-ogp_site_url = "http://example.org/"
+ogp_site_url = "http://example.org/en/latest/"
 ogp_description_length = 50
