@@ -6,7 +6,7 @@ exclude_patterns = ["_build"]
 html_theme = "basic"
 
 ogp_site_name = "Example's Docs!"
-ogp_site_url = "http://example.org/"
-ogp_image = "http://example.org/image33.png"
+ogp_site_url = "http://example.org/en/latest/"
+ogp_image = "http://example.org/en/latest/image33.png"
 ogp_image_alt = "TEST"
 ogp_use_first_image = True
