@@ -6,5 +6,6 @@ exclude_patterns = ["_build"]
 html_theme = "basic"
 
 ogp_site_name = "Example's Docs!"
-ogp_site_url = "http://example.org/"
+ogp_site_url = "http://example.org/en/latest/"
+ogp_image = "_static/image33.png"
 ogp_use_first_image = True
