@@ -6,5 +6,5 @@ exclude_patterns = ["_build"]
 html_theme = "basic"
 
 ogp_site_name = "Example's Docs!"
-ogp_site_url = "http://example.org/"
-ogp_image = "http://example.org/image.png"
+ogp_site_url = "http://example.org/en/latest/"
+ogp_image = "http://example.org/en/latest/image.png"
