@@ -107,6 +107,11 @@ def test_site_name(og_meta_tags):
     assert get_tag_content(og_meta_tags, "site_name") == "Example's Docs!"
 
 
+@pytest.mark.sphinx("html", testroot="sitename-from-project")
+def test_site_name_project(og_meta_tags):
+    assert get_tag_content(og_meta_tags, "site_name") == "Project name"
+
+
 @pytest.mark.sphinx("html", testroot="first-image")
 def test_first_image(og_meta_tags):
     assert (
@@ -279,3 +284,15 @@ def test_rtd_invalid(app: Sphinx, monkeypatch):
 
     with pytest.raises(Exception):
         app.build()
+
+
+# Test no breakage with no configuration
+@pytest.mark.sphinx("html", testroot="rtd-default")
+def test_no_configuration_html(og_meta_tags):
+    assert get_tag_content(og_meta_tags, "type") == "website"
+
+
+# Test no breakage with no configuration
+@pytest.mark.sphinx("dirhtml", testroot="rtd-default")
+def test_no_configuration_dirhtml(og_meta_tags):
+    assert get_tag_content(og_meta_tags, "type") == "website"
